summaryrefslogtreecommitdiffstats
path: root/kaddressbook/views/cardview.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kaddressbook/views/cardview.cpp')
-rw-r--r--kaddressbook/views/cardview.cpp32
1 files changed, 16 insertions, 16 deletions
diff --git a/kaddressbook/views/cardview.cpp b/kaddressbook/views/cardview.cpp
index 9149c6536..110d3be84 100644
--- a/kaddressbook/views/cardview.cpp
+++ b/kaddressbook/views/cardview.cpp
@@ -61,7 +61,7 @@ class CardViewTip : public TQLabel
};
//
// Warning: make sure you use findRef() instead of tqfind() to find an
// item! Only the pointer value is unique in the list.
//
class CardViewItemList : public TQPtrList<CardViewItem>
@@ -316,7 +316,7 @@ void CardViewItem::paintCard( TQPainter *p, TQColorGroup &cg )
// if we are the current item and the view has focus, draw focus rect
if ( mView->currentItem() == this && mView->hasFocus() ) {
- mView->style().drawPrimitive( TQStyle::PE_FocusRect, p,
+ mView->tqstyle().tqdrawPrimitive( TQStyle::PE_FocusRect, p,
TQRect( 0, 0, mView->itemWidth(), h + (2 * mg) ), cg,
TQStyle::Style_FocusAtBorder,
TQStyleOption( isSelected() ? cg.highlight() : cg.base() ) );
@@ -587,7 +587,7 @@ CardView::CardView( TQWidget *tqparent, const char *name )
viewport()->setMouseTracking( true );
viewport()->setFocusProxy( this );
- viewport()->setFocusPolicy( WheelFocus );
+ viewport()->setFocusPolicy(Qt::WheelFocus );
viewport()->setBackgroundMode( PaletteBase );
connect( d->mTimer, TQT_SIGNAL( timeout() ), this, TQT_SLOT( tryShowFullText() ) );
@@ -616,7 +616,7 @@ void CardView::takeItem( CardViewItem *item )
{
if ( d->mCurrentItem == item )
d->mCurrentItem = item->nextItem();
- d->mItemList.take( d->mItemList.findRef( item ) );
+ d->mItemList.take( d->mItemList.tqfindRef( item ) );
setLayoutDirty( true );
}
@@ -843,7 +843,7 @@ void CardView::drawContents( TQPainter *p, int clipx, int clipy,
calcLayout();
// allow setting costum colors in the viewport pale
- TQColorGroup cg = viewport()->palette().active();
+ TQColorGroup cg = viewport()->tqpalette().active();
TQRect clipRect( clipx, clipy, clipw, cliph );
TQRect cardRect;
@@ -953,7 +953,7 @@ void CardView::calcLayout()
CardViewItem *CardView::itemAfter( const CardViewItem *item ) const
{
- d->mItemList.findRef( item );
+ d->mItemList.tqfindRef( item );
return d->mItemList.next();
}
@@ -1022,7 +1022,7 @@ void CardView::contentsMousePressEvent( TQMouseEvent *e )
emit clicked( item );
// The RMB click
- if ( e->button() & TQt::RightButton ) {
+ if ( e->button() & Qt::RightButton ) {
// clear previous selection
bool blocked = signalsBlocked();
blockSignals( true );
@@ -1056,7 +1056,7 @@ void CardView::contentsMousePressEvent( TQMouseEvent *e )
item->tqrepaintCard();
emit selectionChanged();
} else if ( d->mSelectionMode == CardView::Extended ) {
- if ( (e->button() & TQt::LeftButton) && (e->state() & TQt::ShiftButton) ) {
+ if ( (e->button() & Qt::LeftButton) && (e->state() & TQt::ShiftButton) ) {
if ( item == other )
return;
@@ -1070,8 +1070,8 @@ void CardView::contentsMousePressEvent( TQMouseEvent *e )
}
int from, to, a, b;
- a = d->mItemList.findRef( item );
- b = d->mItemList.findRef( other );
+ a = d->mItemList.tqfindRef( item );
+ b = d->mItemList.tqfindRef( other );
from = a < b ? a : b;
to = a > b ? a : b;
@@ -1083,11 +1083,11 @@ void CardView::contentsMousePressEvent( TQMouseEvent *e )
}
emit selectionChanged();
- } else if ( (e->button() & TQt::LeftButton) && (e->state() & TQt::ControlButton) ) {
+ } else if ( (e->button() & Qt::LeftButton) && (e->state() & TQt::ControlButton) ) {
item->setSelected( !item->isSelected() );
item->tqrepaintCard();
emit selectionChanged();
- } else if ( e->button() & TQt::LeftButton ) {
+ } else if ( e->button() & Qt::LeftButton ) {
bool b = signalsBlocked();
blockSignals( true );
selectAll( false );
@@ -1158,7 +1158,7 @@ void CardView::contentsMouseMoveEvent( TQMouseEvent *e )
return;
}
- if ( d->mLastClickOnItem && (e->state() & TQt::LeftButton) &&
+ if ( d->mLastClickOnItem && (e->state() & Qt::LeftButton) &&
((e->pos() - d->mLastClickPos).manhattanLength() > 4)) {
startDrag();
@@ -1218,7 +1218,7 @@ void CardView::keyPressEvent( TQKeyEvent *e )
return;
}
- uint pos = d->mItemList.findRef( d->mCurrentItem );
+ uint pos = d->mItemList.tqfindRef( d->mCurrentItem );
CardViewItem *aItem = 0;
CardViewItem *old = d->mCurrentItem;
@@ -1347,8 +1347,8 @@ void CardView::keyPressEvent( TQKeyEvent *e )
// otherwise, ??????
bool s = ! aItem->isSelected();
int from, to, a, b;
- a = d->mItemList.findRef( aItem );
- b = d->mItemList.findRef( old );
+ a = d->mItemList.tqfindRef( aItem );
+ b = d->mItemList.tqfindRef( old );
from = a < b ? a : b;
to = a > b ? a : b;
@@ -61,7 +61,7 @@ class CardViewTip : public TQLabel
};
//
-// Warning: make sure you use findRef() instead of tqfind() to find an
+// Warning: make sure you use tqfindRef() instead of tqfind() to find an
// item! Only the pointer value is unique in the list.
//